@@ -53,14 +53,14 @@
   (defun-maybe Meadow-version ()))
 
 (product-provide 'fortune-version
-  (product-define "Fortune" nil '(0 1)))
+  (product-define "Fortune" nil '(0 3)))
 
 (defvar fortune-insert-user-agent nil)
 
 (defvar fortune-server "fortune.yahoo.co.jp")
 (defvar fortune-server-top "/fortune/12astro/")
 (defvar fortune-port 80)
-(defvar fortune-coding-system 'euc-japan)
+(defvar fortune-coding-system (static-if (boundp 'MULE) '*euc-japan* 'euc-japan))
 
 ;; for proxy.
 (defvar fortune-proxy-server nil)
